# File: tests/test_fcsigner.py

from os import stat_result

import unittest

from fcsigner.fcsigner import __generate_checksum_file_content as generate_checksum_file_content

class TestFcSigner(unittest.TestCase):


    def test_generate_checksum_file_content_correct_template(self):
        file_name_with_path = "/path/to/test_file.txt"
        file_stats = stat_result((0, 0, 0, 0, 0, 0, 123, 0, 0, 0))
        file_sum = "abc123"

        expected_result = "#test_file.txt 123 bytes\nSHA256 (test_file.txt) = abc123"
        result = generate_checksum_file_content(file_name_with_path, file_stats, file_sum)

        assert result == expected_result


    def test_generate_checksum_file_content_empty_name(self):
        file_name_with_path = ""
        file_stats = stat_result((0, 0, 0, 0, 0, 0, 456, 0, 0, 0))
        file_sum = "def456"

        expected_result = "# 456 bytes\nSHA256 () = def456"
        result = generate_checksum_file_content(file_name_with_path, file_stats, file_sum)

        assert result == expected_result


    def test_generate_checksum_file_content_large_file_size(self):
        file_name_with_path = "/another/path/large_file.bin"
        file_stats = stat_result((0, 0, 0, 0, 0, 0, 2 ** 32, 0, 0, 0))
        file_sum = "789ghi"

        expected_result = "#large_file.bin 4294967296 bytes\nSHA256 (large_file.bin) = 789ghi"
        result = generate_checksum_file_content(file_name_with_path, file_stats, file_sum)

        assert result == expected_result
